@@ -225,4 +225,11 @@ def use_venue(venue_root):
     print s
     return backstage_venue
 
+def venue_from_cwd():
+    cwd = os.getcwd()
+    try:
+        v = Venue(cwd)
+    except:
+        v = None
+    return v
 
